@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 2008, 2010, 2012 Sergey Poznyakoff
+   Copyright (C) 2008-2018 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -285,8 +285,8 @@ init_suffix_index(struct outline_file *file)
 	for (i = 0; i < file->count; i++) {
 	    char *p = malloc(file->index[i].length + 1);
 	    if (!p) {
-		while (i-- >= 0)
-		    free(file->suf_index[i].word);
+		while (i > 0)
+		    free(file->suf_index[--i].word);
 		free(file->suf_index);
 		return 1;
 	    }
